@@ -3,6 +3,7 @@ from io import BytesIO
 from typing import List, Optional, Union
 
 from fastapi import UploadFile
+from fa_common import FileDownloadRef
 
 from .model import File
 
@@ -84,3 +85,9 @@ class BaseClient(abc.ABC):
         self, from_bucket: str, from_path: str, to_bucket: str, to_path: str
     ) -> None:
         pass
+
+    @abc.abstractmethod
+    async def create_temp_file_ref(self, bucket: str, path: str) -> File:
+        """Enable file to be donwloaded without auth via a URL temporarily
+        """
+        pass
