@@ -1,5 +1,12 @@
 from .utils import get_workflow_client, setup_gitlab
-from .service import run_job, get_job_run, get_job_log, create_workflow_project
+from .service import (
+    run_job,
+    get_job_run,
+    get_job_log,
+    create_workflow_project,
+    delete_workflow_project,
+    delete_workflow_user,
+)
 from .models import (
     ScidraModule,
     WorkflowProject,
