@@ -69,6 +69,7 @@ async def run_job(
     job_yaml["run-job"]["image"] = module.docker_image
     job_yaml["run-job"]["variables"]["JOB_PARAMETERS"] = json.dumps(job_data)
     job_yaml["run-job"]["variables"]["FILE_REFS"] = json.dumps(file_refs)
+    job_yaml["run-job"]["variables"]["MODULE_NAME"] = module.name
 
     client = get_workflow_client()
 
@@ -86,7 +87,7 @@ async def get_job_run(user_id: str, job_id: int, include_log: bool = False) -> J
     return await client.get_job(user_id, job_id, include_log)
 
 
-async def get_job_log(user_id: str, job_id: int):
+async def get_job_log(user_id: str, job_id: int) -> bytes:
     client = get_workflow_client()
     logs = await client.get_job_log(user_id, job_id)
     return logs
