@@ -1,10 +1,8 @@
 import os
 import pytest
 
-import oyaml as yaml
-from fa_common import create_app, start_app, utils, force_sync, FileDownloadRef
+from fa_common import create_app, start_app, utils, force_sync
 from fa_common.workflow import (
-    get_workflow_client,
     run_job,
     ScidraModule,
     get_job_run,
