@@ -10,14 +10,14 @@ from pathlib import Path
 from fa_common import create_app, start_app, utils
 from fa_common.storage import get_storage_client
 
-from .conftest import clean_env
+from .conftest import clean_env, TEST_USER_BUCKET
 
 dirname = os.path.dirname(__file__)
 test_data_path = os.path.join(dirname, "data")
 
 
 async def exercise_storage(path: str):
-    bucket_name = "facf-test-bucket"
+    bucket_name = TEST_USER_BUCKET
 
     app = create_app(env_path=path)
     await start_app(app)
